@@ -5,7 +5,10 @@ streamlines.
 
 
 """
-import collections
+from warnings import warn
+import re
+import collections.abc
+from functools import partial
 import numbers
 import numpy as np
 import nibabel as nib
@@ -20,6 +23,8 @@ from dipy.align.imaffine import (transform_centers_of_mass,
 
 from dipy.align.transforms import (TranslationTransform3D,
                                    RigidTransform3D,
+                                   RigidScalingTransform3D,
+                                   RigidIsoScalingTransform3D,
                                    AffineTransform3D)
 
 
@@ -34,7 +39,9 @@ from dipy.io.image import load_nifti, save_nifti
 
 __all__ = ["syn_registration", "register_dwi_to_template",
            "write_mapping", "read_mapping", "resample",
-           "center_of_mass", "translation", "rigid", "affine",
+           "center_of_mass", "translation",
+           "rigid_isoscaling", "rigid_scaling",
+           "rigid", "affine", "motion_correction",
            "affine_registration", "register_series",
            "register_dwi_series", "streamline_registration"]
 
@@ -117,6 +124,7 @@ def syn_registration(moving, static,
     backward : ndarray (..., 3)
         The vector field describing the backward warping from the target to the
         source.
+
     """
     level_iters = level_iters or [10, 10, 5]
 
@@ -143,11 +151,10 @@ def syn_registration(moving, static,
 def register_dwi_to_template(dwi, gtab, dwi_affine=None, template=None,
                              template_affine=None, reg_method="syn",
                              **reg_kwargs):
-    """
-    Register DWI data to a template through the B0 volumes.
+    """ Register DWI data to a template through the B0 volumes.
 
     Parameters
-    -----------
+    ----------
     dwi : 4D array, nifti image or str
         Containing the DWI data, or full path to a nifti file with DWI.
     gtab : GradientTable or sequence of strings
@@ -216,8 +223,7 @@ def register_dwi_to_template(dwi, gtab, dwi_affine=None, template=None,
 
 
 def write_mapping(mapping, fname):
-    """
-    Write out a syn registration mapping to a nifti file
+    """ Write out a syn registration mapping to a nifti file.
 
     Parameters
     ----------
@@ -230,14 +236,14 @@ def write_mapping(mapping, fname):
     The data in the file is organized with shape (X, Y, Z, 2, 3, 3), such
     that the forward mapping in each voxel is in `data[i, j, k, 0, :, :]` and
     the backward mapping in each voxel is in `data[i, j, k, 0, :, :]`.
+
     """
     mapping_data = np.array([mapping.forward.T, mapping.backward.T]).T
     save_nifti(fname, mapping_data, mapping.codomain_world2grid)
 
 
 def read_mapping(disp, domain_img, codomain_img, prealign=None):
-    """
-    Read a syn registration mapping from a nifti file
+    """ Read a syn registration mapping from a nifti file.
 
     Parameters
     ----------
@@ -256,6 +262,7 @@ def read_mapping(disp, domain_img, codomain_img, prealign=None):
     Notes
     -----
     See :func:`write_mapping` for the data format expected.
+
     """
     if isinstance(disp, str):
         disp_data, disp_affine = load_nifti(disp)
@@ -313,6 +320,7 @@ def resample(moving, static, moving_affine=None, static_affine=None,
     -------
     A Nifti1Image class instance with the data from the moving object
     resampled into the space of the static object.
+
     """
 
     static, static_affine, moving, moving_affine, between_affine = \
@@ -327,199 +335,6 @@ def resample(moving, static, moving_affine=None, static_affine=None,
     return nib.Nifti1Image(resampled, static_affine)
 
 
-def center_of_mass(moving, static, static_affine=None, moving_affine=None,
-                   starting_affine=None, reg=None):
-    """
-    Implements a center of mass transform
-
-    Parameters
-    ----------
-    moving : array, nifti image or str
-        Containing the data for the moving object, or full path to a nifti file
-        with the moving data.
-
-    moving_affine : 4x4 array, optional
-        An affine transformation associated with the moving object. Required if
-        data is provided as an array. If provided together with nifti/path,
-        will over-ride the affine that is in the nifti.
-
-    static : array, nifti image or str
-        Containing the data for the static object, or full path to a nifti file
-        with the moving data.
-
-    static_affine : 4x4 array, optional
-        An affine transformation associated with the static object. Required if
-        data is provided as an array. If provided together with nifti/path,
-        will over-ride the affine that is in the nifti.
-
-    starting_affine: 4x4 array, optional
-        Initial guess for the transformation between the spaces.
-
-    reg : not needed here. Use None
-
-    Returns
-    -------
-    transformed, transform.affine : array with moving data resampled to the
-    static space after computing the center of mass transformation and the
-    affine 4x4 associated with the transformation.
-    """
-    static, static_affine, moving, moving_affine, starting_affine = \
-        _handle_pipeline_inputs(moving, static,
-                                moving_affine=moving_affine,
-                                static_affine=static_affine,
-                                starting_affine=starting_affine)
-    transform = transform_centers_of_mass(static, static_affine,
-                                          moving, moving_affine)
-    return transform.affine
-
-
-def translation(moving, static, static_affine=None, moving_affine=None,
-                starting_affine=None, reg=None):
-    """
-    Implements a translation transform
-
-    Parameters
-    ----------
-    moving : array, nifti image or str
-        Containing the data for the moving object, or full path to a nifti file
-        with the moving data.
-
-    moving_affine : 4x4 array, optional
-        An affine transformation associated with the moving object. Required if
-        data is provided as an array. If provided together with nifti/path,
-        will over-ride the affine that is in the nifti.
-
-    static : array, nifti image or str
-        Containing the data for the static object, or full path to a nifti file
-        with the moving data.
-
-    static_affine : 4x4 array, optional
-        An affine transformation associated with the static object. Required if
-        data is provided as an array. If provided together with nifti/path,
-        will over-ride the affine that is in the nifti.
-
-    starting_affine: 4x4 array, optional
-        Initial guess for the transformation between the spaces.
-
-    reg : AffineRegistration class instance.
-
-    Returns
-    -------
-    transformed, transform.affine : array with moving data resampled to the
-    static space after computing the translation transformation and the
-    affine 4x4 associated with the transformation.
-    """
-    static, static_affine, moving, moving_affine, starting_affine = \
-        _handle_pipeline_inputs(moving, static,
-                                moving_affine=moving_affine,
-                                static_affine=static_affine,
-                                starting_affine=starting_affine)
-    transform = TranslationTransform3D()
-    translation = reg.optimize(static, moving, transform, None,
-                               static_affine, moving_affine,
-                               starting_affine=starting_affine)
-
-    return translation.affine
-
-
-def rigid(moving, static, static_affine=None, moving_affine=None,
-          starting_affine=None, reg=None):
-    """
-    Implements a rigid transform
-
-    Parameters
-    ----------
-    moving : array, nifti image or str
-        Containing the data for the moving object, or full path to a nifti file
-        with the moving data.
-
-    moving_affine : 4x4 array, optional
-        An affine transformation associated with the moving object. Required if
-        data is provided as an array. If provided together with nifti/path,
-        will over-ride the affine that is in the nifti.
-
-    static : array, nifti image or str
-        Containing the data for the static object, or full path to a nifti file
-        with the moving data.
-
-    static_affine : 4x4 array, optional
-        An affine transformation associated with the static object. Required if
-        data is provided as an array. If provided together with nifti/path,
-        will over-ride the affine that is in the nifti.
-
-    starting_affine: 4x4 array, optional
-        Initial guess for the transformation between the spaces.
-
-    reg : AffineRegistration class instance.
-
-    Returns
-    -------
-    transformed, transform.affine : array with moving data resampled to the
-    static space after computing the rigid transformation and the affine 4x4
-    associated with the transformation.
-    """
-    static, static_affine, moving, moving_affine, starting_affine = \
-        _handle_pipeline_inputs(moving, static,
-                                moving_affine=moving_affine,
-                                static_affine=static_affine,
-                                starting_affine=starting_affine)
-    transform = RigidTransform3D()
-    rigid = reg.optimize(static, moving, transform, None,
-                         static_affine, moving_affine,
-                         starting_affine=starting_affine)
-    return rigid.affine
-
-
-def affine(moving, static, static_affine=None, moving_affine=None,
-           starting_affine=None, reg=None):
-    """
-    Implements a translation transform
-
-    Parameters
-    ----------
-    moving : array, nifti image or str
-        Containing the data for the moving object, or full path to a nifti file
-        with the moving data.
-
-    moving_affine : 4x4 array, optional
-        An affine transformation associated with the moving object. Required if
-        data is provided as an array. If provided together with nifti/path,
-        will over-ride the affine that is in the nifti.
-
-    static : array, nifti image or str
-        Containing the data for the static object, or full path to a nifti file
-        with the moving data.
-
-    static_affine : 4x4 array, optional
-        An affine transformation associated with the static object. Required if
-        data is provided as an array. If provided together with nifti/path,
-        will over-ride the affine that is in the nifti.
-
-    starting_affine: 4x4 array, optional
-        Initial guess for the transformation between the spaces.
-
-    reg : AffineRegistration class instance.
-
-    Returns
-    -------
-    transformed, transform.affine : array with moving data resampled to the
-    static space after computing the affine transformation and the affine
-    4x4 associated with the transformation.
-    """
-
-    static, static_affine, moving, moving_affine, starting_affine = \
-        _handle_pipeline_inputs(moving, static,
-                                moving_affine=moving_affine,
-                                static_affine=static_affine,
-                                starting_affine=starting_affine)
-    transform = AffineTransform3D()
-    xform = reg.optimize(static, moving, transform, None,
-                         static_affine, moving_affine,
-                         starting_affine=starting_affine)
-
-    return xform.affine
-
-
 def affine_registration(moving, static,
                         moving_affine=None,
                         static_affine=None,
@@ -529,10 +344,13 @@ def affine_registration(moving, static,
                         level_iters=None,
                         sigmas=None,
                         factors=None,
+                        ret_metric=False,
+                        moving_mask=None,
+                        static_mask=None,
                         **metric_kwargs):
-
     """
-    Find the affine transformation between two 3D images.
+    Find the affine transformation between two 3D images. Alternatively, find
+    the combination of several linear transformations.
 
     Parameters
     ----------
@@ -540,24 +358,27 @@ def affine_registration(moving, static,
         Containing the data for the moving object, or full path to a nifti file
         with the moving data.
 
+    static : array, nifti image or str
+        Containing the data for the static object, or full path to a nifti file
+        with the moving data.
+
     moving_affine : 4x4 array, optional
         An affine transformation associated with the moving object. Required if
         data is provided as an array. If provided together with nifti/path,
         will over-ride the affine that is in the nifti.
 
-    static : array, nifti image or str
-        Containing the data for the static object, or full path to a nifti file
-        with the moving data.
-
     static_affine : 4x4 array, optional
         An affine transformation associated with the static object. Required if
         data is provided as an array. If provided together with nifti/path,
         will over-ride the affine that is in the nifti.
 
-    pipeline : sequence, optional
-        Sequence of transforms to use in the gradual fitting of the full
-        affine. Default: (executed from left to right):
-        `[center_of_mass, translation, rigid, affine]`
+    pipeline : list of str, optional
+        Sequence of transforms to use in the gradual fitting. Default: gradual
+        fit of the full affine (executed from left to right):
+        ``["center_of_mass", "translation", "rigid", "affine"]``
+        Alternatively, any other combination of the following registration
+        methods might be used: center_of_mass, translation, rigid,
+        rigid_isoscaling, rigid_scaling and affine.
 
     starting_affine: 4x4 array, optional
         Initial guess for the transformation between the spaces.
@@ -566,20 +387,6 @@ def affine_registration(moving, static,
     metric : str, optional.
         Currently only supports 'MI' for MutualInformationMetric.
 
-    nbins : int, optional
-        MutualInformationMetric key-word argument: the number of bins to be
-        used for computing the intensity histograms. The default is 32.
-
-    sampling_proportion : None or float in interval (0, 1], optional
-        MutualInformationMetric key-word argument: There are two types of
-        sampling: dense and sparse. Dense sampling uses all voxels for
-        estimating the (joint and marginal) intensity histograms, while
-        sparse sampling uses a subset of them. If `sampling_proportion` is
-        None, then dense sampling is used. If `sampling_proportion` is a
-        floating point value in (0,1] then sparse sampling is used,
-        where `sampling_proportion` specifies the proportion of voxels to
-        be used. The default is None (dense sampling).
-
     level_iters : sequence, optional
         AffineRegistration key-word argument: the number of iterations at each
         scale of the scale space. `level_iters[0]` corresponds to the coarsest
@@ -597,12 +404,39 @@ def affine_registration(moving, static,
         scale space (one factor for each scale). By default, the sequence of
         factors will be [4, 2, 1].
 
+    ret_metric : boolean, optional
+        Set it to True to return the value of the optimized coefficients and
+        the optimization quality metric.
+
+    moving_mask : array, shape (S', R', C') or (R', C'), optional
+        moving image mask that defines which pixels in the moving image
+        are used to calculate the mutual information.
+
+    static_mask : array, shape (S, R, C) or (R, C), optional
+        static image mask that defines which pixels in the static image
+        are used to calculate the mutual information.
+
+    nbins : int, optional
+        MutualInformationMetric key-word argument: the number of bins to be
+        used for computing the intensity histograms. The default is 32.
+
+    sampling_proportion : None or float in interval (0, 1], optional
+        MutualInformationMetric key-word argument: There are two types of
+        sampling: dense and sparse. Dense sampling uses all voxels for
+        estimating the (joint and marginal) intensity histograms, while
+        sparse sampling uses a subset of them. If `sampling_proportion` is
+        None, then dense sampling is used. If `sampling_proportion` is a
+        floating point value in (0,1] then sparse sampling is used,
+        where `sampling_proportion` specifies the proportion of voxels to
+        be used. The default is None (dense sampling).
+
     Returns
     -------
-    transformed, affine : array with moving data resampled to the static space
-    after computing the affine transformation and the affine 4x4
-    associated with the transformation.
-
+    transformed : array with moving data resampled to the static space
+    after computing the affine transformation
+    affine : the affine 4x4 associated with the transformation.
+    xopt : the value of the optimized coefficients.
+    fopt : the value of the optimization quality metric.
 
     Notes
     -----
@@ -610,12 +444,14 @@ def affine_registration(moving, static,
     that gradually approximates the final registration. If the final default
     step (`affine`) is ommitted, the resulting affine may not have all 12
     degrees of freedom adjusted.
+
     """
-    pipeline = pipeline or [center_of_mass, translation, rigid, affine]
+    pipeline = pipeline or ["center_of_mass", "translation", "rigid", "affine"]
     level_iters = level_iters or [10000, 1000, 100]
     sigmas = sigmas or [3, 1, 0.0]
     factors = factors or [4, 2, 1]
 
+    starting_was_supplied = starting_affine is not None
     static, static_affine, moving, moving_affine, starting_affine = \
         _handle_pipeline_inputs(moving, static,
                                 moving_affine=moving_affine,
@@ -631,13 +467,51 @@ def affine_registration(moving, static,
                                 sigmas=sigmas,
                                 factors=factors)
 
+    # Convert pipeline to sanitized list of str
+    pipeline = list(pipeline)
+    for fi, func in enumerate(pipeline):
+        if callable(func):
+            for key, val in _METHOD_DICT.items():
+                if func is val[0]:  # if they passed the callable equiv.
+                    pipeline[fi] = func = key
+                    break
+        if not isinstance(func, str) or func not in _METHOD_DICT:
+            raise ValueError(f'pipeline[{fi}] must be one of '
+                             f'{list(_METHOD_DICT)}, got {repr(func)}')
+
+    if pipeline == ["center_of_mass"] and ret_metric:
+        raise ValueError("center of mass registration cannot return any "
+                         "quality metric.")
+
     # Go through the selected transformation:
     for func in pipeline:
-        starting_affine = func(moving, static,
-                               static_affine=static_affine,
-                               moving_affine=moving_affine,
-                               starting_affine=starting_affine,
-                               reg=affreg)
+        if func == "center_of_mass":
+
+            if starting_affine is not None and starting_was_supplied:
+                wm = "starting_affine overwritten by center_of_mass transform"
+                warn(wm, UserWarning, stacklevel=2)
+
+            # multiply images by masks for transform_centers_of_mass
+            static_masked, moving_masked = static, moving
+            if static_mask is not None:
+                static_masked = static*static_mask
+            if moving_mask is not None:
+                moving_masked = moving*moving_mask
+
+            transform = transform_centers_of_mass(static_masked, static_affine,
+                                                  moving_masked, moving_affine)
+            starting_affine = transform.affine
+
+        else:
+            transform = _METHOD_DICT[func][1]()
+            xform, xopt, fopt \
+                = affreg.optimize(static, moving, transform, None,
+                                  static_affine, moving_affine,
+                                  starting_affine=starting_affine,
+                                  ret_metric=True,
+                                  static_mask=static_mask,
+                                  moving_mask=moving_mask)
+            starting_affine = xform.affine
 
     # After doing all that, resample once at the end:
     affine_map = AffineMap(starting_affine,
@@ -646,11 +520,48 @@ def affine_registration(moving, static,
 
     resampled = affine_map.transform(moving)
 
+    # Return the optimization metric only if requested
+    if ret_metric:
+        return resampled, starting_affine, xopt, fopt
     return resampled, starting_affine
 
 
+center_of_mass = partial(affine_registration, pipeline=['center_of_mass'])
+center_of_mass.__doc__ = ("Implements a center of mass transform. "
+                          "Based on `affine_registration()`.")
+
+translation = partial(affine_registration, pipeline=['translation'])
+translation.__doc__ = ("Implements a translation transform. "
+                       "Based on `affine_registration()`.")
+
+rigid = partial(affine_registration, pipeline=['rigid'])
+rigid.__doc__ = ("Implements a rigid transform. "
+                 "Based on `affine_registration()`.")
+
+rigid_isoscaling = partial(affine_registration, pipeline=['rigid_isoscaling'])
+rigid_isoscaling.__doc__ = ("Implements a rigid isoscaling transform. "
+                            "Based on `affine_registration()`.")
+
+rigid_scaling = partial(affine_registration, pipeline=['rigid_scaling'])
+rigid_scaling.__doc__ = ("Implements a rigid scaling transform. "
+                         "Based on `affine_registration()`.")
+
+affine = partial(affine_registration, pipeline=['affine'])
+affine.__doc__ = ("Implements an affine transform. "
+                  "Based on `affine_registration()`.")
+
+
+_METHOD_DICT = dict(  # mapping from str key -> (callable, class) tuple
+    center_of_mass=(center_of_mass, None),
+    translation=(translation, TranslationTransform3D),
+    rigid_isoscaling=(rigid_isoscaling, RigidIsoScalingTransform3D),
+    rigid_scaling=(rigid_scaling, RigidScalingTransform3D),
+    rigid=(rigid, RigidTransform3D),
+    affine=(affine, AffineTransform3D))
+
+
 def register_series(series, ref, pipeline=None, series_affine=None,
-                    ref_affine=None):
+                    ref_affine=None, static_mask=None):
     """Register a series to a reference image.
 
     Parameters
@@ -673,13 +584,18 @@ def register_series(series, ref, pipeline=None, series_affine=None,
         The affine. If provided, this input will over-ride the affine provided
         together with the nifti img or file.
 
+    static_mask : array, shape (S, R, C) or (R, C), optional
+        static image mask that defines which pixels in the static image
+        are used to calculate the mutual information.
+
     Returns
     -------
     xformed, affines : 4D array with transformed data and a (4,4,n) array
     with 4x4 matrices associated with each of the volumes of the input moving
     data that was used to transform it into register with the static data.
+
     """
-    pipeline = pipeline or [center_of_mass, translation, rigid, affine]
+    pipeline = pipeline or ["center_of_mass", "translation", "rigid", "affine"]
 
     series, series_affine = read_img_arr_or_path(series,
                                                  affine=series_affine)
@@ -709,17 +625,19 @@ def register_series(series, ref, pipeline=None, series_affine=None,
                 this_moving, ref,
                 moving_affine=series_affine,
                 static_affine=ref_affine,
-                pipeline=pipeline)
+                pipeline=pipeline,
+                static_mask=static_mask)
             xformed[..., ii] = transformed
             affines[..., ii] = reg_affine
 
     return xformed, affines
 
 
-def register_dwi_series(data, gtab, affine=None, b0_ref=0, pipeline=None):
-    """
-    Register a DWI series to the mean of the B0 images in that series (all
-    first registered to the first B0 volume)
+def register_dwi_series(data, gtab, affine=None, b0_ref=0, pipeline=None,
+                        static_mask=None):
+    """Register a DWI series to the mean of the B0 images in that series.
+
+    all first registered to the first B0 volume
 
     Parameters
     ----------
@@ -742,8 +660,11 @@ def register_dwi_series(data, gtab, affine=None, b0_ref=0, pipeline=None):
 
     pipeline : list of callables, optional.
         The transformations to perform in sequence (from left to right):
-        Default: `[center_of_mass, translation, rigid, affine]`
+        Default: ``[center_of_mass, translation, rigid, affine]``
 
+    static_mask : array, shape (S, R, C) or (R, C), optional
+        static image mask that defines which pixels in the static image
+        are used to calculate the mutual information.
 
     Returns
     -------
@@ -752,18 +673,18 @@ def register_dwi_series(data, gtab, affine=None, b0_ref=0, pipeline=None):
     transforms associated with each of the
 
     """
-    if pipeline is None:
-        [center_of_mass, translation, rigid, affine]
+    pipeline = pipeline or ["center_of_mass", "translation", "rigid", "affine"]
 
     data, affine = read_img_arr_or_path(data, affine=affine)
-    if isinstance(gtab, collections.Sequence):
+    if isinstance(gtab, collections.abc.Sequence):
         gtab = dpg.gradient_table(*gtab)
 
     if np.sum(gtab.b0s_mask) > 1:
         # First, register the b0s into one image and average:
         b0_img = nib.Nifti1Image(data[..., gtab.b0s_mask], affine)
         trans_b0, b0_affines = register_series(b0_img, ref=b0_ref,
-                                               pipeline=pipeline)
+                                               pipeline=pipeline,
+                                               static_mask=static_mask)
         ref_data = np.mean(trans_b0, -1)
     else:
         # There's only one b0 and we register everything to it
@@ -775,7 +696,8 @@ def register_dwi_series(data, gtab, affine=None, b0_ref=0, pipeline=None):
     series_arr = np.concatenate([ref_data, moving_data], -1)
     series = nib.Nifti1Image(series_arr, affine)
 
-    xformed, affines = register_series(series, ref=0, pipeline=pipeline)
+    xformed, affines = register_series(series, ref=0, pipeline=pipeline,
+                                       static_mask=static_mask)
     # Cut out the part pertaining to that first volume:
     affines = affines[..., 1:]
     xformed = xformed[..., 1:]
@@ -790,10 +712,19 @@ def register_dwi_series(data, gtab, affine=None, b0_ref=0, pipeline=None):
     return nib.Nifti1Image(data_array, affine), affine_array
 
 
+motion_correction = partial(register_dwi_series, pipeline=["center_of_mass",
+                                                           "translation",
+                                                           "rigid", "affine"])
+motion_correction.__doc__ = re.sub('Register.*?volume', 'Apply a motion '
+                                   'correction to a DWI dataset '
+                                   '(Between-Volumes Motion correction)',
+                                   register_dwi_series.__doc__,
+                                   flags=re.DOTALL)
+
+
 def streamline_registration(moving, static, n_points=100,
                             native_resampled=False):
-    """
-    Register two collections of streamlines ('bundles') to each other
+    """ Register two collections of streamlines ('bundles') to each other.
 
     Parameters
     ----------
@@ -816,6 +747,7 @@ def streamline_registration(moving, static, n_points=100,
 
     matrix : array (4, 4)
         The affine transformation that takes us from 'moving' to 'static'
+
     """
     # Load the streamlines, if you were given a file-name
     if isinstance(moving, str):
