@@ -2,7 +2,6 @@
 
 import abc
 import numpy as np
-import scipy as sp
 from numpy import gradient
 from scipy import ndimage
 from dipy.align import vector_fields as vfu
@@ -243,18 +242,21 @@ class CCMetric(SimilarityMetric):
         re-orienting the gradients in the voxel space using the corresponding
         affine transformations.
         """
+        min_size = self.radius * 2 + 1
 
         def invalid_image_size(image):
-            min_size = self.radius * 2 + 1
-            return any([size < min_size for size in image.shape])
+            return any(size < min_size for size in image.shape)
 
-        msg = ("Each image dimension should be superior to 2 * radius + 1."
-               "Decrease CCMetric radius or increase your image size")
+        msg = ("Each image dimension should be superior to 2 * radius + 1 "
+               f"({min_size}). Decrease CCMetric radius ({self.radius}) or "
+               "increase your image size (shape=%(shape)s).")
 
         if invalid_image_size(self.static_image):
-            raise ValueError("Static image size is too small. " + msg)
+            raise ValueError("Static image size is too small. " +
+                             msg % dict(shape=self.static_image.shape))
         if invalid_image_size(self.moving_image):
-            raise ValueError("Moving image size is too small. " + msg)
+            raise ValueError("Moving image size is too small. " +
+                             msg % dict(shape=self.moving_image.shape))
 
         self.factors = self.precompute_factors(self.static_image,
                                                self.moving_image,
@@ -302,7 +304,7 @@ class CCMetric(SimilarityMetric):
             self.gradient_static, self.factors, self.radius)
         displacement = np.array(displacement)
         for i in range(self.dim):
-            displacement[..., i] = ndimage.filters.gaussian_filter(
+            displacement[..., i] = ndimage.gaussian_filter(
                 displacement[..., i], self.sigma_diff)
         return displacement
 
@@ -317,7 +319,7 @@ class CCMetric(SimilarityMetric):
                                                           self.radius)
         displacement = np.array(displacement)
         for i in range(self.dim):
-            displacement[..., i] = ndimage.filters.gaussian_filter(
+            displacement[..., i] = ndimage.gaussian_filter(
                 displacement[..., i], self.sigma_diff)
         return displacement
 
@@ -611,8 +613,7 @@ class EMMetric(SimilarityMetric):
                                                              sigma_reg_2,
                                                              None)
         for i in range(self.dim):
-            step[..., i] = ndimage.filters.gaussian_filter(step[..., i],
-                                                           self.smooth)
+            step[..., i] = ndimage.gaussian_filter(step[..., i], self.smooth)
         return step
 
     def get_energy(self):
@@ -866,8 +867,7 @@ class SSDMetric(SimilarityMetric):
                                                                sigma_reg_2,
                                                                None)
         for i in range(self.dim):
-            step[..., i] = ndimage.filters.gaussian_filter(step[..., i],
-                                                           self.smooth)
+            step[..., i] = ndimage.gaussian_filter(step[..., i], self.smooth)
         return step
 
     def get_energy(self):
