@@ -1,6 +1,8 @@
 # -*- coding: utf-8 -*-
+from packaging.version import Version
+
 import numpy as np
-from distutils.version import LooseVersion
+
 from dipy.reconst.multi_voxel import multi_voxel_fit
 from dipy.reconst.base import ReconstModel, ReconstFit
 from dipy.reconst.cache import Cache
@@ -398,7 +400,7 @@ class MapmriModel(ReconstModel, Cache):
 
             data_norm = np.asarray(data / data[self.gtab.b0s_mask].mean())
             c = cvxpy.Variable(M.shape[1])
-            if LooseVersion(cvxpy.__version__) < LooseVersion('1.1'):
+            if Version(cvxpy.__version__) < Version('1.1'):
                 design_matrix = cvxpy.Constant(M) * c
             else:
                 design_matrix = cvxpy.Constant(M) @ c
@@ -413,7 +415,7 @@ class MapmriModel(ReconstModel, Cache):
                     lopt * cvxpy.quad_form(c, laplacian_matrix)
                 )
             M0 = M[self.gtab.b0s_mask, :]
-            if LooseVersion(cvxpy.__version__) < LooseVersion('1.1'):
+            if Version(cvxpy.__version__) < Version('1.1'):
                 constraints = [(M0[0] * c) == 1,
                                (K * c) >= -0.1]
             else:
@@ -506,6 +508,8 @@ class MapmriFit(ReconstFit):
 
         Parameters
         ----------
+        sphere : Sphere
+            A Sphere instance with vertices, edges and faces attributes.
         s : unsigned int
             radial moment of the ODF
 
@@ -1112,7 +1116,7 @@ def mapmri_phi_1d(n, q, mu):
 
     qn = 2 * np.pi * mu * q
     H = hermite(n)(qn)
-    i = np.complex(0, 1)
+    i = complex(0, 1)
     f = mfactorial(n)
 
     k = i ** (-n) / np.sqrt(2 ** (n) * f)
