@@ -1,6 +1,8 @@
 # -*- coding: utf-8 -*-
+from packaging.version import Version
+
 import numpy as np
-from distutils.version import LooseVersion
+
 from dipy.reconst.cache import Cache
 from dipy.core.geometry import cart2sphere
 from dipy.reconst.multi_voxel import multi_voxel_fit
@@ -350,7 +352,7 @@ class QtdmriModel(Cache):
             elif np.isscalar(self.laplacian_weighting):
                 lopt = self.laplacian_weighting
             c = cvxpy.Variable(M.shape[1])
-            if LooseVersion(cvxpy.__version__) < LooseVersion('1.1'):
+            if Version(cvxpy.__version__) < Version('1.1'):
                 design_matrix = cvxpy.Constant(M) * c
             else:
                 design_matrix = cvxpy.Constant(M) @ c
@@ -360,7 +362,7 @@ class QtdmriModel(Cache):
             )
             if self.constrain_q0:
                 # just constraint first and last, otherwise the solver fails
-                if LooseVersion(cvxpy.__version__) < LooseVersion('1.1'):
+                if Version(cvxpy.__version__) < Version('1.1'):
                     constraints = [M0[0] * c == 1, M0[-1] * c == 1]
                 else:
                     constraints = [M0[0] @ c == 1, M0[-1] @ c == 1]
@@ -380,7 +382,7 @@ class QtdmriModel(Cache):
             elif np.isscalar(self.l1_weighting):
                 alpha = self.l1_weighting
             c = cvxpy.Variable(M.shape[1])
-            if LooseVersion(cvxpy.__version__) < LooseVersion('1.1'):
+            if Version(cvxpy.__version__) < Version('1.1'):
                 design_matrix = cvxpy.Constant(M) * c
             else:
                 design_matrix = cvxpy.Constant(M) @ c
@@ -390,7 +392,7 @@ class QtdmriModel(Cache):
             )
             if self.constrain_q0:
                 # just constraint first and last, otherwise the solver fails
-                if LooseVersion(cvxpy.__version__) < LooseVersion('1.1'):
+                if Version(cvxpy.__version__) < Version('1.1'):
                     constraints = [M0[0] * c == 1, M0[-1] * c == 1]
                 else:
                     constraints = [M0[0] @ c == 1, M0[-1] @ c == 1]
@@ -431,7 +433,7 @@ class QtdmriModel(Cache):
             elif np.isscalar(self.l1_weighting):
                 alpha = self.l1_weighting
             c = cvxpy.Variable(M.shape[1])
-            if LooseVersion(cvxpy.__version__) < LooseVersion('1.1'):
+            if Version(cvxpy.__version__) < Version('1.1'):
                 design_matrix = cvxpy.Constant(M) * c
             else:
                 design_matrix = cvxpy.Constant(M) @ c
@@ -442,7 +444,7 @@ class QtdmriModel(Cache):
             )
             if self.constrain_q0:
                 # just constraint first and last, otherwise the solver fails
-                if LooseVersion(cvxpy.__version__) < LooseVersion('1.1'):
+                if Version(cvxpy.__version__) < Version('1.1'):
                     constraints = [M0[0] * c == 1, M0[-1] * c == 1]
                 else:
                     constraints = [M0[0] @ c == 1, M0[-1] @ c == 1]
@@ -1330,8 +1332,6 @@ def qtdmri_isotropic_signal_matrix(radial_order, time_order, us, ut, q, tau):
 
 def qtdmri_eap_matrix_(radial_order, time_order, us, ut, grid,
                        normalization=False):
-    sqrtC = 1.
-    sqrtut = 1.
     sqrtCut = 1.
     if normalization:
         sqrtC = qtdmri_mapmri_normalization(us)
@@ -1583,7 +1583,6 @@ def qtdmri_isotropic_laplacian_reg_matrix(ind_mat, us, ut,
 
     if normalization:
         temporal_normalization = qtdmri_temporal_normalization(ut) ** 2
-        spatial_normalization = np.zeros_like(regularization_matrix)
         j, ll = ind_mat[:, :2].T
         pre_spatial_norm = qtdmri_mapmri_isotropic_normalization(j, ll, us[0])
         spatial_normalization = np.outer(pre_spatial_norm, pre_spatial_norm)
@@ -1885,7 +1884,7 @@ def qtdmri_anisotropic_scaling(data, q, bvecs, tau):
     return us, ut, R
 
 
-def design_matrix_spatial(bvecs, qvals, dtype=None):
+def design_matrix_spatial(bvecs, qvals):
     """  Constructs design matrix for DTI weighted least squares or
     least squares fitting. (Basser et al., 1994a)
 
@@ -1981,7 +1980,7 @@ def l1_crossvalidation(b0s_mask, E, M, weight_array=np.linspace(0, .4, 21)):
         while cv_old >= cv_new and counter < weight_array.shape[0]:
             alpha = weight_array[counter]
             c = cvxpy.Variable(M.shape[1])
-            if LooseVersion(cvxpy.__version__) < LooseVersion('1.1'):
+            if Version(cvxpy.__version__) < Version('1.1'):
                 design_matrix = cvxpy.Constant(M[test]) * c
                 recovered_signal = cvxpy.Constant(M[sub]) * c
             else:
@@ -2043,7 +2042,7 @@ def elastic_crossvalidation(b0s_mask, E, M, L, lopt,
         cv_old = errorlist[i, 0]
         cv_new = errorlist[i, 0]
         c = cvxpy.Variable(M.shape[1])
-        if LooseVersion(cvxpy.__version__) < LooseVersion('1.1'):
+        if Version(cvxpy.__version__) < Version('1.1'):
             design_matrix = cvxpy.Constant(M[test]) * c
             recovered_signal = cvxpy.Constant(M[sub]) * c
         else:
