@@ -1,14 +1,14 @@
 import numpy as np
 import itertools
 
-from numpy.testing import (assert_array_equal, run_module_suite,
-                           assert_equal, assert_raises)
+from numpy.testing import assert_array_equal, assert_equal, assert_raises
 from dipy.testing.memory import get_type_refcount
 from dipy.testing import assert_arrays_equal
 
 from dipy.segment.clustering import QuickBundles
 
-import dipy.segment.metric as dipymetric
+import dipy.segment.featurespeed as dipysfeature
+import dipy.segment.metricspeed as dipysmetric
 from dipy.segment.clustering_algorithms import quickbundles
 import dipy.tracking.streamline as streamline_utils
 
@@ -26,7 +26,7 @@ clusters_truth = [[0, 1], [2, 4], [3]]
 
 def test_quickbundles_empty_data():
     threshold = 10
-    metric = dipymetric.SumPointwiseEuclideanMetric()
+    metric = dipysmetric.SumPointwiseEuclideanMetric()
     clusters = quickbundles([], metric, threshold)
     assert_equal(len(clusters), 0)
     assert_equal(len(clusters.centroids), 0)
@@ -44,7 +44,7 @@ def test_quickbundles_wrong_metric():
 def test_quickbundles_shape_uncompatibility():
     # QuickBundles' old default metric (AveragePointwiseEuclideanMetric,
     #  aka MDF) requires that all streamlines have the same number of points.
-    metric = dipymetric.AveragePointwiseEuclideanMetric()
+    metric = dipysmetric.AveragePointwiseEuclideanMetric()
     qb = QuickBundles(threshold=20., metric=metric)
     assert_raises(ValueError, qb.cluster, data)
 
@@ -54,8 +54,8 @@ def test_quickbundles_shape_uncompatibility():
     qb = QuickBundles(threshold=20.)
     clusters1 = qb.cluster(data)
 
-    feature = dipymetric.ResampleFeature(nb_points=18)
-    metric = dipymetric.AveragePointwiseEuclideanMetric(feature)
+    feature = dipysfeature.ResampleFeature(nb_points=18)
+    metric = dipysmetric.AveragePointwiseEuclideanMetric(feature)
     qb = QuickBundles(threshold=20., metric=metric)
     clusters2 = qb.cluster(data)
 
@@ -89,7 +89,7 @@ def test_quickbundles_2D():
     # Theoretically, using a threshold above the following value will not
     # produce expected results.
     threshold = np.sqrt(2*(10**2))-np.sqrt(2)
-    metric = dipymetric.SumPointwiseEuclideanMetric()
+    metric = dipysmetric.SumPointwiseEuclideanMetric()
     ordering = np.arange(len(data))
     for i in range(100):
         rng.shuffle(ordering)
@@ -150,7 +150,7 @@ def test_quickbundles_streamlines():
 
 def test_quickbundles_with_python_metric():
 
-    class MDFpy(dipymetric.Metric):
+    class MDFpy(dipysmetric.Metric):
         def are_compatible(self, shape1, shape2):
             return shape1 == shape2
 
@@ -183,7 +183,7 @@ def test_quickbundles_with_python_metric():
 
 
 def test_quickbundles_with_not_order_invariant_metric():
-    metric = dipymetric.AveragePointwiseEuclideanMetric()
+    metric = dipysmetric.AveragePointwiseEuclideanMetric()
     qb = QuickBundles(threshold=np.inf, metric=metric)
 
     streamline = np.arange(10*3, dtype=dtype).reshape((-1, 3))
@@ -203,7 +203,3 @@ def test_quickbundles_memory_leaks():
     qb.cluster(data)
     # At this point, all memoryviews created during clustering should be freed.
     assert_equal(get_type_refcount(type_name_pattern), initial_types_refcount)
-
-
-if __name__ == '__main__':
-    run_module_suite()
