@@ -7,8 +7,7 @@ from scipy.spatial.distance import cdist
 import numpy as np
 from nibabel.affines import apply_affine
 from nibabel.streamlines import ArraySequence as Streamlines
-from dipy.tracking.streamlinespeed import (compress_streamlines, length,
-                                           set_number_of_points)
+from dipy.tracking.streamlinespeed import length, set_number_of_points
 from dipy.tracking.distances import bundles_distances_mdf
 import dipy.tracking.utils as ut
 from dipy.core.geometry import dist_to_corner
@@ -49,7 +48,7 @@ def relist_streamlines(points, offsets):
     an offsets array return the streamlines as a list of shorter arrays.
 
     Parameters
-    -----------
+    ----------
     points : array
     offsets : array
 
@@ -685,7 +684,7 @@ def values_from_volume(data, streamlines, affine):
         The voxel_to_rasmm matrix, typically from a NIFTI file.
 
     Returns
-    ---------
+    -------
     array or list (depending on the input) : values interpolate to each
         coordinate along the length of each streamline.
 
