@@ -13,15 +13,15 @@ from numpy.testing import (assert_array_equal, assert_array_almost_equal,
                            assert_raises, assert_allclose,
                            assert_almost_equal, assert_equal)
 
+from dipy.tracking.streamlinespeed import (
+    compress_streamlines, length, set_number_of_points,
+)
 from dipy.tracking.streamline import Streamlines
-from dipy.tracking.streamline import (set_number_of_points,
-                                      length,
-                                      relist_streamlines,
+from dipy.tracking.streamline import (relist_streamlines,
                                       unlist_streamlines,
                                       center_streamlines,
                                       transform_streamlines,
                                       select_random_set_of_streamlines,
-                                      compress_streamlines,
                                       select_by_rois,
                                       orient_by_rois,
                                       orient_by_streamline,
@@ -521,15 +521,16 @@ def test_unlist_relist_streamlines():
 def test_deform_streamlines():
     # Create Random deformation field
     deformation_field = np.random.randn(200, 200, 200, 3)
-    # Specify stream2grid and grid2world
-    stream2grid = np.array([[np.random.randn(1)[0], 0, 0, 0],
-                            [0, np.random.randn(1)[0], 0, 0],
-                            [0, 0, np.random.randn(1)[0], 0],
-                            [0, 0, 0, 1]])
-    grid2world = np.array([[np.random.randn(1)[0], 0, 0, 0],
-                           [0, np.random.randn(1)[0], 0, 0],
-                           [0, 0, np.random.randn(1)[0], 0],
-                           [0, 0, 0, 1]])
+    stream2grid = np.array([
+        [-0.13152201, -0.52553149, -0.06759869, -0.80014208],
+        [1.01579851, 0.19840874, 0.18875411, 0.81826065],
+        [-0.07047617, -0.9290094, -0.55623385, 0.55165017],
+        [0., 0., 0., 1.]])
+    grid2world = np.array([
+        [0.83354727, 1.33876877, 1.0218087, 0.12809569],
+        [0.83571344, 0.63824941, 0.20564267, 0.82740437],
+        [-0.26574668, -0.66695577, 0.11636694, -0.02620037],
+        [0., 0., 0., 1.]])
     stream2world = np.dot(stream2grid, grid2world)
 
     # Deform streamlines (let two grid spaces be the same for simplicity)
@@ -732,6 +733,25 @@ def test_compress_streamlines():
         assert_array_almost_equal(cspecial_streamline, cstreamline_python)
 
 
+def test_compress_streamlines_identical_points():
+
+    sl_1 = np.array([[1, 1, 1], [1, 1, 1], [2, 2, 2], [3, 3, 3], [3, 3, 3]])
+    sl_2 = np.array([[1, 1, 1], [1, 1, 1], [1, 1, 1], [2, 2, 2]])
+    sl_3 = np.array([[1, 1, 1], [1, 1, 1], [1, 1, 1], [1, 1, 1],
+                     [2, 2, 2], [2, 2, 2], [2, 2, 2], [3, 3, 3], [3, 3, 3]])
+    sl_4 = np.array([[1, 1, 1], [1, 1, 1], [1, 1, 1], [1, 1, 1], [2, 2, 2],
+                    [3, 3, 3], [3, 3, 3], [1, 1, 1]])
+    new_sl_1 = compress_streamlines(sl_1)
+    new_sl_2 = compress_streamlines(sl_2)
+    new_sl_3 = compress_streamlines(sl_3)
+    new_sl_4 = compress_streamlines(sl_4)
+    npt.assert_array_equal(new_sl_1, np.array([[1, 1, 1], [3, 3, 3]]))
+    npt.assert_array_equal(new_sl_2, np.array([[1, 1, 1], [2, 2, 2]]))
+    npt.assert_array_equal(new_sl_3, new_sl_1)
+    npt.assert_array_equal(new_sl_4, np.array([[1, 1, 1], [3, 3, 3],
+                                               [1, 1, 1]]))
+
+
 def test_compress_streamlines_memory_leaks():
     # Test some dtypes
     dtypes = [np.float32, np.float64, np.int32, np.int64]
@@ -1196,7 +1216,7 @@ def test_cluster_confidence():
 
     cci = cluster_confidence(test_streamlines, override=True)
 
-    assert_equal(cci[0], cci[2])
+    assert_almost_equal(cci[0], cci[2])
     assert_true(cci[1] > cci[0])
 
     # 3 parallel streamlines
