@@ -22,7 +22,8 @@ if has_fury:
 skip_it = use_xvfb == 'skip'
 
 
-@pytest.mark.skipif(skip_it or not has_fury, reason='Requires FURY')
+@pytest.mark.skipif(skip_it or not has_fury,
+                    reason='Requires FURY')
 def test_horizon_flow():
 
     s1 = 10 * np.array([[0, 0, 0],
@@ -126,9 +127,10 @@ def test_horizon_flow():
         npt.assert_equal(os.path.exists(os.path.join(out_dir, 'tmp_x.png')),
                          True)
 
+        npt.assert_raises(ValueError, hz_flow.run, input_files=input_files,
+                          roi_colors=(0.2, 0.2))
 
-
-
-if __name__ == '__main__':
-
-    test_horizon_flow()
+        hz_flow.run(input_files=input_files, stealth=True, roi_colors=[0.5, ],
+                    out_dir=out_dir, out_stealth_png='tmp_x.png')
+        npt.assert_equal(os.path.exists(os.path.join(out_dir, 'tmp_x.png')),
+                         True)
