@@ -32,7 +32,6 @@ First, we import all the modules we need from dipy as follows:
 import numpy as np
 import dipy.reconst.shm as shm
 import dipy.direction.peaks as dp
-import dipy.reconst.dti as dti
 import matplotlib.pyplot as plt
 
 from dipy.denoise.localpca import mppca
@@ -40,7 +39,6 @@ from dipy.core.gradients import gradient_table, unique_bvals_tolerance
 from dipy.io.gradients import read_bvals_bvecs
 from dipy.io.image import load_nifti
 from dipy.segment.mask import median_otsu
-from dipy.reconst.csdeconv import auto_response_ssst
 from dipy.reconst.mcsd import (auto_response_msmt,
                                mask_for_response_msmt,
                                response_from_mask_msmt)
@@ -48,8 +46,6 @@ from dipy.segment.tissue import TissueClassifierHMRF
 from dipy.reconst.mcsd import MultiShellDeconvModel, multi_shell_fiber_response
 from dipy.viz import window, actor
 
-from dipy.direction.peaks import peaks_from_model
-
 from dipy.data import get_sphere, get_fnames
 sphere = get_sphere('symmetric724')
 
